/*  
Template Name: mlpdesign07.1 Khaki
Version: Pure CSS version
Author:webmasterneo, MLP Design
Author URI: http://www.mlpdesign.net/
*/

/* Global Settings */
@import url(https://fonts.googleapis.com/css?family=Open+Sans);
body {
background: #000;
background: -moz-linear-gradient(top, #7c803d 0%, #000000 75%, #000000 100%);
background: -webkit-gradient(left top, left bottom, color-stop(0%, #7c803d), color-stop(75%, #000000), color-stop(100%, #000000));
background: -webkit-linear-gradient(top, #7c803d 0%, #000000 75%, #000000 100%);
background: -o-linear-gradient(top, #7c803d 0%, #000000 75%, #000000 100%);
background: -ms-linear-gradient(top, #7c803d 0%, #000000 75%, #000000 100%);
background: linear-gradient(to bottom, #7c803d 0%, #000000 75%, #000000 100%);
filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#7c803d', endColorstr='#000000', GradientType=0 );
	color: #111;
	margin: 0;
	font-family: 'Open Sans', sans-serif;
	font-size: 14px;
	line-height: 18px;
	min-width: 600px;
}
h1 {
	font-size: 20px;
	line-height: 24px;
}
h2 {
	font-size: 18px;
	line-height: 22px;
}
h3 {
	font-size: 16px;
	line-height: 20px;
}
a {
	background-color: inherit;
	color: #996;
	text-decoration: none;
}
a:hover {
	text-decoration: underline;
}
blockquote {
	background-color: inherit;
	color: #999;
	font: italic 15px "Times New Roman", serif;
	border-left: 5px solid #996;
	padding: 2px 15px;
}

/* Wrapper Settings */
#wrapper {
	background: #fff;
	border: none;
	padding: 10px;
	margin: 1% auto;
	width: 90%;
}

#body {
	margin: 0;
}

#container {
	padding: 0;
	margin: 0;
	}

/* Other Settings*/

#banner {
	position: relative;
	padding: 10px;
	height: 175px;
	border: 0px;
	color: #fff;
	background: #abab83;
	background: -moz-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: -webkit-gradient(left top, left bottom, color-stop(0%, #abab83), color-stop(0%, #abab83), color-stop(50%, #abab83), color-stop(51%, #a1a172), color-stop(100%, #a1a172));
	background: -webkit-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: -o-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: -ms-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: linear-gradient(to bottom, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#abab83', endColorstr='#a1a172', GradientType=0 );
}

#banner h1 {
	font-size: 32px;
}

#banner h1 em {
	font-style: normal;
	text-decoration: none;
	color: #111;
}

#show-menu {
	display: none;
}
.responsive {
	background-color: inherit;
	color: #fff;
	text-align: left;
	font-weight: normal;
	font-size: 1.5em;
	padding: 0;
	position: absolute;
	top: 80%;
	display: none;
}

ul#topnav {
	list-style-type: none;
	margin: 0 0 0 1%;
	display: table;
	padding: 0;
	overflow: hidden;
	width: 60%;
	position: absolute;
	bottom: 0;
}

ul#topnav li {
	display: table-cell;
	text-align: center;
}

ul#topnav li a {
	background: #333;
	color: #999;
	border: none;
	display: block;
	margin-right: 5px;
	padding: 5px 0px;
	text-decoration: none;
	font-size: 12px;
}

ul#topnav li a.active,
ul#topnav li a.active:hover {
	background: #fff;
	color: #333;
}

ul#topnav li a:hover {
	background: #cc9;
	color: #111;
}

#sidebar {
	background: #fff;
	float: right;
	width: 200px;
	margin: -175px 1% 50px auto;
	padding: 15px;
	font-size: 12px;
	-webkit-box-shadow: 25px 0px 25px -25px rgba(0, 0, 0, 0.45),
		-25px 0px 25px -25px rgba(0, 0, 0, 0.45);
	-moz-box-shadow: 25px 0px 25px -25px rgba(0, 0, 0, 0.45),
		-25px 0px 25px -25px rgba(0, 0, 0, 0.45);
	box-shadow: 25px 0px 25px -25px rgba(0, 0, 0, 0.45),
		-25px 0px 25px -25px rgba(0, 0, 0, 0.45);
	position: relative;
}

#sidebar h2 {
	background-color: inherit;
	color: #996;
	font: normal 16px Arial, sans-serif;
	border-bottom: 2px solid #996;
	padding: 8px 0 5px 0;
}

#sidebar ul {
	list-style: none;
	padding: 2px;
	margin: 0;
}

#sidebar ul li {
	list-style-position: inside;
	padding: 0 0 10px 20px;
	text-indent: -1em;
}

#sidebar ul li a {
	background-color: inherit;
	color: #333;
	text-decoration: none;
	padding: 5px 2px;
	display: block;
}

#sidebar ul li a:hover {
	background-color: #cc9;
	color: #fff;
}

#sidebar ul li a:before {
	content: "\00BB  ";
	color: #996;
}

#content {
	text-align: left;
	padding: 20px;
	margin-right: 245px;
}

#content h1 {
	font: normal 18px Arial, sans-serif;
	padding: 0;
}

#content ul {
	list-style: none;
}

#content ul li {
	padding: 2px 0 2px 10px;
	margin: 0;
}

#content ul li:before {
	content: "\00BB  ";
	color: #996;
}

#content .item {
	line-height: 1.25em;
	margin: 0;
}

#content .item p {
	text-align: justify;
}

#content .item span {
	background-color: inherit;
	color: #999;
	font-size: 11px;
}

#footer {
	padding: 10px;
	height: 20px;
	border: 0px;
	color: #333;
	font-size: 12px;
	background: #abab83;
	background: -moz-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: -webkit-gradient(left top, left bottom, color-stop(0%, #abab83), color-stop(0%, #abab83), color-stop(50%, #abab83), color-stop(51%, #a1a172), color-stop(100%, #a1a172));
	background: -webkit-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: -o-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: -ms-linear-gradient(top, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	background: linear-gradient(to bottom, #abab83 0%, #abab83 0%, #abab83 50%, #a1a172 51%, #a1a172 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#abab83', endColorstr='#a1a172', GradientType=0 );
	clear: both;
}

#footer a {
	background-color: inherit;
	color: #333;
}

#footer a:hover {
	background-color: inherit;
	color: #fff;
	text-decoration: none;
}

#footer span.left {
	text-align: left;
	padding-left: 15px;
	float: left;
}

#footer span.right {
	text-align: right;
	padding-right: 15px;
	float: right;
}

#footer p.show-footer {
	margin: 0;
	display: none;
}

#credits {
	width: 90%;
	background-color: inherit;
	color: #999;
	position: relative;
	bottom: 0;
	padding: 10px 0;
	font: normal 11px Arial, sans-serif;
	text-align: right;
	margin: 0 auto;
}

#credits a {
	background-color: inherit;
	color: #999;
	text-decoration: none;
}

#credits a:hover {
	background-color: inherit;
	color: #fff;
	text-decoration: none;
}

/* Begin responsive styles */
@media screen and (max-width : 700px){

body { font-size:12px; }
blockquote {
	font-size: 13px;
	border-left-width: 3px;
	padding: 1px 5px 1px 10px;
	margin: 0;
}
/* banner */
/*#banner { height:170px;}*/
#banner h1 {font-size:28px;}
#banner p {width:60%;}

/* menu */
ul#topnav {display:none;}
.responsive { display:block;}
#show-menu:checked ~ ul#topnav {display: block; position: absolute; top:100%; width:50%; margin:0 0 0 -8%; overflow:visible;}
ul#topnav li { display: block; text-align:left; margin:0 0 1px 15%;}
ul#topnav li a { padding-left:20px; border-radius: 0px; -moz-border-radius: 0px; -webkit-border-radius: 0px; font-size:10px;}
/*ul#topnav li a:hover { background: rgba(255,0,85,1); color:rgba(255,255,255,255);}*/
ul#topnav li a.active, ul#topnav li a.active:hover {    background: #eee;  color: #000;}


/* sidebar */
#sidebar { width: 28%; padding:5px; font-size:10px; line-height:1.25em; }
#sidebar h2 { font-size:12px; }

/* content */
#content { margin-right: 33%;}
#content h1 { font-size:14px; font-weight:bold;}
#content .item span { font-size:10px;}
#content ul {margin-left:0; padding-left:0;}
#content ul li {margin-left:0; padding-left:0;}


/* footer */
#footer { font-size:10px; text-align: center; padding-bottom:20px;}
#footer span {display:none;}
#footer p.show-footer {display: block; }
#credits { font-size:80%; text-align:center;}
}